.. role:: hidden
    :class: hidden-section


botorch.utils
========================================================
.. automodule:: botorch.utils


Constraints
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: botorch.utils.constraints
		:members:

Containers
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: botorch.utils.containers
		:members:

Objective
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: botorch.utils.objective
		:members:

Rounding
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: botorch.utils.rounding
		:members:

Sampling
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: botorch.utils.sampling
		:members:

Sampling from GP priors
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: botorch.utils.gp_sampling
		:members:

Testing
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: botorch.utils.testing
		:members:

Torch
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: botorch.utils.torch
		:members:

Transformations
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: botorch.utils.transforms
		:members:

Feasible Volume
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: botorch.utils.feasible_volume
		:members:

Multi-Objective Utilities
-------------------------------------------

Abstract Box Decompositions
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: botorch.utils.multi_objective.box_decompositions.box_decomposition
    	:members:

Box Decomposition List
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: botorch.utils.multi_objective.box_decompositions.box_decomposition_list
    	:members:

Box Decomposition Utilities
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: botorch.utils.multi_objective.box_decompositions.utils
    	:members:

Box Decompositions [DEPRECATED - use botorch..utils.multi_objective.box_decompositions]
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: botorch.utils.multi_objective.box_decomposition
		:members:

Dominated Partitionings
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: botorch.utils.multi_objective.box_decompositions.dominated
		:members:

Hypervolume
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: botorch.utils.multi_objective.hypervolume
		:members:

Non-dominated Partitionings
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: botorch.utils.multi_objective.box_decompositions.non_dominated
		:members:

Pareto
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: botorch.utils.multi_objective.pareto
		:members:

Scalarization
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: botorch.utils.multi_objective.scalarization
		:members:
